Documentation
¶
Index ¶
Constants ¶
const ( // Name of this module Name = "necrobrowser" // Description of this module Description = "Post-phishing automation that hijacks the harvested web session in a dockerized Chrome Headless" // Author of this module Author = "Muraena Team" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type InstrumentNecrobrowser ¶
type InstrumentNecrobrowser struct {
// gSuite, github
Provider string `json:"provider" binding:"required"`
DebuggingPort int `json:"debugPort" binding:"required"`
// classic credentials including 2fa token if any
Username string `json:"username"`
Password string `json:"password"`
Token string `json:"token"`
// cookie jar
SessionCookies []SessionCookie `json:"sessionCookies"`
// keywords to search if target is a webmail or in general search bars
// for example: password, credentials, vpn, etc..
Keywords []string `json:"keywords"`
}
type Necrobrowser ¶
type Necrobrowser struct {
session.SessionModule
Enabled bool
Endpoint string
Token string
Portal string
}
Necrobrowser module
func Load ¶
func Load(s *session.Session) (m *Necrobrowser, err error)
Load configures the module by initializing its main structure and variables
func (*Necrobrowser) Author ¶
func (module *Necrobrowser) Author() string
Author returns the module author
func (*Necrobrowser) Description ¶
func (module *Necrobrowser) Description() string
Description returns the module description
func (*Necrobrowser) InstrumentNecroBrowser ¶
func (module *Necrobrowser) InstrumentNecroBrowser(instrument *InstrumentNecrobrowser) (err error)
func (*Necrobrowser) Prompt ¶ added in v0.1.2
func (module *Necrobrowser) Prompt(what string)
Prompt prints module status based on the provided parameters
type SessionCookie ¶
type SessionCookie struct {
Name string `json:"name"`
Value string `json:"value"`
Domain string `json:"domain"`
Expires string `json:"expires"`
Path string `json:"path"`
HTTPOnly bool `json:"httpOnly"`
Secure bool `json:"secure"`
}
SessionCookie type is needed to interact with NecroBrowser
Click to show internal directories.
Click to hide internal directories.